# Changelog

### 0.0.2 - January 4th

 - Fixed pydt command
 - Added support to the `@XMLDT.tag` decorator
 - Added tests to _Skel_ code
 - Support for `father` and `gfather` accessors

### 0.0.1

 - First version